==> orthanc_0.4.0.orig.tar.gz: Orthanc-0.4.0/Core/HttpServer/EmbeddedResourceHttpHandler.cpp <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
 * Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * In addition, as a special exception, the copyright holders of this
 * program give permission to link the code of its release with the
 * OpenSSL project's "OpenSSL" library (or with modified versions of it
 * that use the same license as the "OpenSSL" library), and distribute
 * the linked executables. You must obey the GNU General Public License
 * in all respects for all of the code used other than "OpenSSL". If you
 * modify file(s) with this exception, you may extend this exception to
 * your version of the file(s), but you are not obligated to do so. If
 * you do not wish to do so, delete this exception statement from your
 * version. If you delete this exception statement from all source files
 * in the program, then also delete it here.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#include "EmbeddedResourceHttpHandler.h"

#include "../OrthancException.h"

#include <stdio.h>
#include <glog/logging.h>


namespace Orthanc
{
  EmbeddedResourceHttpHandler::EmbeddedResourceHttpHandler(
    const std::string& baseUri,
    EmbeddedResources::DirectoryResourceId resourceId)
  {
    Toolbox::SplitUriComponents(baseUri_, baseUri);
    resourceId_ = resourceId;
  }


  bool EmbeddedResourceHttpHandler::IsServedUri(const UriComponents& uri)
  {
    return Toolbox::IsChildUri(baseUri_, uri);
  }


  void EmbeddedResourceHttpHandler::Handle(
    HttpOutput& output,
    const std::string& method,
    const UriComponents& uri,
    const Arguments& headers,
    const Arguments& arguments,
    const std::string&)
  {
    if (method != "GET")
    {
      output.SendMethodNotAllowedError("GET");
      return;
    }

    std::string resourcePath = Toolbox::FlattenUri(uri, baseUri_.size());
    std::string contentType = Toolbox::AutodetectMimeType(resourcePath);

    try
    {
      const void* buffer = EmbeddedResources::GetDirectoryResourceBuffer(resourceId_, resourcePath.c_str());
      size_t size = EmbeddedResources::GetDirectoryResourceSize(resourceId_, resourcePath.c_str());
      output.AnswerBufferWithContentType(buffer, size, contentType);
    }
    catch (OrthancException& e)
    {
      LOG(WARNING) << "Unable to find HTTP resource: " << resourcePath;
      output.SendHeader(Orthanc_HttpStatus_404_NotFound);
    }
  } 
}

==> orthanc_0.5.2.orig.tar.gz: Orthanc-0.5.2/Core/HttpServer/EmbeddedResourceHttpHandler.cpp <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2013 Medical Physics Department, CHU of Liege,
 * Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * In addition, as a special exception, the copyright holders of this
 * program give permission to link the code of its release with the
 * OpenSSL project's "OpenSSL" library (or with modified versions of it
 * that use the same license as the "OpenSSL" library), and distribute
 * the linked executables. You must obey the GNU General Public License
 * in all respects for all of the code used other than "OpenSSL". If you
 * modify file(s) with this exception, you may extend this exception to
 * your version of the file(s), but you are not obligated to do so. If
 * you do not wish to do so, delete this exception statement from your
 * version. If you delete this exception statement from all source files
 * in the program, then also delete it here.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#include "EmbeddedResourceHttpHandler.h"

#include "../OrthancException.h"
#include "HttpOutput.h"

#include <stdio.h>
#include <glog/logging.h>


namespace Orthanc
{
  EmbeddedResourceHttpHandler::EmbeddedResourceHttpHandler(
    const std::string& baseUri,
    EmbeddedResources::DirectoryResourceId resourceId)
  {
    Toolbox::SplitUriComponents(baseUri_, baseUri);
    resourceId_ = resourceId;
  }


  bool EmbeddedResourceHttpHandler::IsServedUri(const UriComponents& uri)
  {
    return Toolbox::IsChildUri(baseUri_, uri);
  }


  void EmbeddedResourceHttpHandler::Handle(
    HttpOutput& output,
    Orthanc_HttpMethod method,
    const UriComponents& uri,
    const Arguments& headers,
    const Arguments& arguments,
    const std::string&)
  {
    if (method != Orthanc_HttpMethod_Get)
    {
      output.SendMethodNotAllowedError("GET");
      return;
    }

    std::string resourcePath = Toolbox::FlattenUri(uri, baseUri_.size());
    std::string contentType = Toolbox::AutodetectMimeType(resourcePath);

    try
    {
      const void* buffer = EmbeddedResources::GetDirectoryResourceBuffer(resourceId_, resourcePath.c_str());
      size_t size = EmbeddedResources::GetDirectoryResourceSize(resourceId_, resourcePath.c_str());
      output.AnswerBufferWithContentType(buffer, size, contentType);
    }
    catch (OrthancException& e)
    {
      LOG(WARNING) << "Unable to find HTTP resource: " << resourcePath;
      output.SendHeader(Orthanc_HttpStatus_404_NotFound);
    }
  } 
}
